<?php

/**
* Parent command
*/
require_once($_CONF['path'] . 'plugins/fortune/commands/BaseCommand.class.php');

/**
* This command will install the fortune module for Geeklog
*
* @author Tony Bibbs <tony AT geeklog DOT com>
*
*/
class install extends BaseCommand {
    /**
    * Constructor
    *
    * @author Tony Bibbs <tony AT geeklog DOT net>
    * @access public
    *
    */
    function install()
    {
        $this->_doSecurityCheck();
    }

    /**
    * Checks to make sure user has access to this
    * command
    *
    * @author Tony Bibbs <tony AT geeklog DOT net
    * @access private
    *
    */
    function _doSecurityCheck()
    {
        global $_USER, $_LANG_FORTUNE;

        if (!SEC_inGroup('Root')) {
            $display .= COM_siteHeader('menu');
            $display .= COM_startBlock($_LANG_FORTUNE['accessdenied']);
            $display .= $_LANG_FORTUNE['accessdeniedmsg'];
            $display .= COM_endBlock();
            $display .= COM_siteFooter();
            COM_errorLog("User {$_USER['username']} tried to illegally access one of the fortune administration commands",1);
            echo $display;
            exit;
        }
    }

    /**
    * Actually installs the fortune module
    *
    * @author Tony Bibbs <tony AT geeklog DOT com>
    *
    */
    function executeCommand()
    {
        global $_TABLES;

        COM_errorLog('Attempting to install fortune module');
   
        $steps = Array();
 
        // Installs the Fortune plugin
        $createsql = "CREATE TABLE {$_TABLES['fortune']} ("
            . "fortune_id mediumint(8) DEFAULT '0' NOT NULL auto_increment,"
            . "fortune_uid mediumint(8) DEFAULT '1' NOT NULL,"
            . "fortune_date datetime,"
            . "fortune_author varchar(128) DEFAULT '' NOT NULL,"
            . "fortune_text text NOT NULL,"
            . "issubmission tinyint(1) NOT NULL DEFAULT 1,"
            . "owner_id mediumint(8) DEFAULT 1 NOT NULL,"
            . "group_id mediumint(8) DEFAULT 2 NOT NULL,"
            . "perm_owner tinyint(1) unsigned NOT NULL DEFAULT 3,"
            . "perm_group tinyint(1) unsigned NOT NULL DEFAULT 3,"
            . "perm_members tinyint(1) unsigned NOT NULL DEFAULT 2,"
            . "perm_anon tinyint(1) unsigned NOT NULL DEFAULT 2,"
            . "PRIMARY KEY (fortune_id)"
            . ")";

        COM_errorLog("Attempting to create table fortune for Fortune plugin", 1);
        DB_query($createsql,1);

        if (DB_error()) {
            return false;
        }
        COM_errorLog('...success',1);
        $steps['createtablefortune'] = 1;

        // Create the Fortune admin security group
        COM_errorLog("Attempting to create Fortune admin group", 1);
        DB_query("INSERT INTO {$_TABLES['groups']} (grp_name, grp_descr) "
            . "VALUES ('Fortune Admin', 'Users in this group can administer the Fortune plugin')",1);
        if (DB_error()) {
            return $steps;
        }
        COM_errorLog('...success',1);
        $steps['insertgroup'] = 1;

        // Save the grp id for later uninstall
        COM_errorLog('About to save group_id to vars table for use during uninstall',1);
        DB_query("INSERT INTO {$_TABLES['vars']} VALUES ('fortune_group_id', LAST_INSERT_ID())",1);
        if (DB_error()) {
            return $steps;
        }
        COM_errorLog('...success',1);
        $steps['savedgroupid'] = 1;

        $group_id = DB_getItem($_TABLES['vars'], 'value', "name = 'fortune_group_id'");

        // Add Fortune features
        COM_errorLog('Attempting to add fortune.edit feature',1);
        DB_query("INSERT INTO {$_TABLES['features']} (ft_name, ft_descr) "
            . "VALUES ('fortune.edit','Access to Fortune editor')",1);
        if (DB_error()) {
            return $steps;
        }
        $edit_id = DB_insertId();
        COM_errorLog('...success',1);
        $steps['insertedfeatureedit'] = 1;

        COM_errorLog('Attempting to add fortune.delete feature',1);
        DB_query("INSERT INTO {$_TABLES['features']} (ft_name, ft_descr) "
            . "VALUES ('fortune.delete','Ability to delete Fortune')",1);
        if (DB_error()) {
            return $steps;
        }
        $delete_id = DB_insertId();
        COM_errorLog('...success',1);
        $steps['insertedfeaturedelete'] = 1;

        // Now add the features to the group
        COM_errorLog('Attempting to give Fortune Admin group access to fortune.edit feature',1);
        DB_query("INSERT INTO {$_TABLES['access']} (acc_ft_id, acc_grp_id) VALUES ($edit_id, $group_id)");
        if (DB_error()) {
            return $steps;
        }
        COM_errorLog('...success',1);
        $steps['addededittogroup'] = 1;

        COM_errorLog('Attempting to give Fortune Admin group access to fortune.delete feature',1);
        DB_query("INSERT INTO {$_TABLES['access']} (acc_ft_id, acc_grp_id) VALUES ($delete_id, $group_id)",1);
        if (DB_error()) {
            return $steps;
        }
        COM_errorLog('...success',1);
        $steps['addeddeletetogroup'] = 1;

        // OK, now give Root users access to this plugin now! NOTE: Root group should always be 1
        COM_errorLog('Attempting to give all users in Root group access Fortune admin group',1);
        DB_query("INSERT INTO {$_TABLES['group_assignments']} VALUES ($group_id, NULL, 1)");
        if (DB_error()) {
            return $steps;
        }

        COM_errorLog('...success',1);
        $steps['addedrootuserstogroup'] = 1;

        // Register the plugin with Geeklog
        if (DB_count($_TABLES['plugins'],'pi_name','fortune') > 0) {
            COM_errorLog('Attempting to remove fortune rentry prior to adding an updated entry',1);
            DB_query("DELETE FROM {$_TABLES['plugins']} WHERE pi_name = 'fortune'");
            if (DB_error()) {
                return $steps;
            }
            COM_errorLog('...success',1);
        }

        COM_errorLog('Registering Fortune plugin with Geeklog', 1);
        DB_delete($_TABLES['plugins'],'pi_name','fortune');
        DB_query("INSERT INTO {$_TABLES['plugins']} (pi_name, pi_version, pi_gl_version, pi_homepage, pi_enabled) "
            . "VALUES ('fortune', '0.1', '1.3.7sr1', 'http://www.tonybibbs.com', 1)");
        DB_query("INSERT INTO {$_TABLES['vars']} VALUES ('fortune','1')");

        if (DB_error()) {
            return $steps;
        }
        COM_errorLog('...success',1);
        COM_errorLog('Succesfully installed the Fortune Plugin!',1);

        return Array();
    }
}

?>
