<?php

/**
* Parent command object
*/
require_once($_CONF['path'] . 'plugins/fortune/commands/BaseCommand.class.php');

/**
* Uninstalls the fortune module
*
* @author Tony Bibbs <tony AT geeklog DOT com>
*
*/
class uninstall extends BaseCommand {
    /**
    * Constructor
    *
    * @author Tony Bibbs <tony AT geeklog DOT net>
    * @access public
    *
    */
    function uninstall()
    {
        $this->_doSecurityCheck();
    }

    /**
    * Checks to make sure user has access to this
    * command
    *
    * @author Tony Bibbs <tony AT geeklog DOT net
    * @access private
    *
    */
    function _doSecurityCheck()
    {
        global $_USER, $_LANG_FORTUNE;

        if (!SEC_inGroup('Root')) {
            $display .= COM_siteHeader('menu');
            $display .= COM_startBlock($_LANG_FORTUNE['accessdenied']);
            $display .= $_LANG_FORTUNE['accessdeniedmsg'];
            $display .= COM_endBlock();
            $display .= COM_siteFooter();
            COM_errorLog("User {$_USER['username']} tried to illegally access one of the fortune administration commands",1);
            echo $display;
            exit;
        }
    }

    /**
    * Uninstalls the fortune module's data structures
    *
    * @author Tony Bibbs <tony AT geeklog DOT net>
    * @access public
    * @param array $steps Optional array of steps that were completed during the installation
    *
    */
    function executeCommand($steps = '')
    {
        global $_TABLES;

        if (empty($steps) OR $steps['createtable'] == 1) {
            // Remove the fortune table
            COM_errorLog('Dropping fortune table',1);
            DB_query("DROP TABLE {$_TABLES['fortune']}");
            COM_errorLog('...success',1);
        }

        // Remove security for this plugin

        // Remove the fortune admin group
        $grp_id = DB_getItem($_TABLES['vars'], 'value', "name = 'fortune_group_id'");

        if (empty($steps) OR $steps['insertgroup'] == 1) {
            COM_errorLog('Attempting to remove the Fortune Admin Group', 1);
            DB_query("DELETE FROM {$_TABLES['groups']} WHERE grp_id = $grp_id");
            COM_errorLog('...success',1);
        }

        // Remove related features
        $edit_id = DB_getItem($_TABLES['features'], 'ft_id', "ft_name = 'fortune.edit'");
        $delete_id = DB_getItem($_TABLES['features'], 'ft_id', "ft_name = 'fortune.delete'");

        if (empty($steps) OR $steps['addededittogroup'] == 1) {
            // Remove access to those features
            COM_errorLog('Attempting to remove rights to fortune.edit from all groups',1);
            DB_query("DELETE FROM {$_TABLES['access']} WHERE acc_ft_id = $edit_id");
            COM_errorLog('...success',1);
        }

        if (empty($steps) OR $steps['addeddeletetogroup'] == 1) {
            // Remove access to those features
            COM_errorLog('Attempting to remove rights to fortune.delete from all groups',1);
            DB_query("DELETE FROM {$_TABLES['access']} WHERE acc_ft_id = $delete_id");
            COM_errorLog('...success',1);
        }

        if (empty($steps) OR $steps['addedrootuserstogroup'] == 1) {
            // Remove root users from the group
            COM_errorLog('Attempting to remove root users from admin of fortunes');
            DB_query("DELETE FROM {$_TABLES['group_assignments']} WHERE ug_main_grp_id = $grp_id");
            COM_errorLog('...success',1);
        }

        if (empty($steps) OR $steps['insertedfeatureedit'] == 1) {
            COM_errorLog('Attempting to remove the fortune.edit feature',1);
            DB_query("DELETE FROM {$_TABLES['features']} WHERE ft_id = $edit_id");
            COM_errorLog('...success',1);
        }

        if (empty($steps) OR $steps['insertedfeaturedelete'] == 1) {
            COM_errorLog('Attempting to remove the fortune.delete feature',1);
            DB_query("DELETE FROM {$_TABLES['features']} WHERE ft_id = $delete_id");
            COM_errorLog('...success',1);
        }

        if (empty($steps) OR $steps['savedgroupid']) {
            COM_errorLog('Attempting to remove the group id from the vars table',1);
            DB_query("DELETE FROM {$_TABLES['vars']} WHERE name = 'fortune_group_id'");
            COM_errorLog('success',1);
        }

        // Unregister the plugin with Geeklog
        // Always attempt to remove these entries or lib-common.php would still
        // try and read our functions.inc file ...
        COM_errorLog('Attempting to unregister the plugin from Geeklog',1);
        DB_query("DELETE FROM {$_TABLES['plugins']} WHERE pi_name = 'fortune'");
        DB_query("DELETE FROM {$_TABLES['vars']} WHERE name = 'fortune'");
        COM_errorLog('...success',1);

        COM_errorLog('leaving plugin_uninstall_fortune',1);
    }

}
